# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`zend_common::license`](#zend_common--license): Upload a Zend product license to the proper directory
* [`zend_common::repo`](#zend_common--repo): Configure the ZendPHP package repositories depending on OS and version

## Classes

### <a name="zend_common--license"></a>`zend_common::license`

Upload a Zend product license to the proper directory

#### Examples

##### With license URL

```puppet
class { 'zend_common::license':
  source    => 'puppet:///modules/<MODULE_NAME>/zend/license',
  notify    => Class['zendhq::service'],
  subscribe => Class['zendhq::package'],
}
```

##### With license text

```puppet
$license = Deferred('vault_lookup::lookup',["licenses/zendhq"], 'https://vault.server.lcl:8200',)
class { 'zend_common::license':
  content    => $license,
}
```

#### Parameters

The following parameters are available in the `zend_common::license` class:

* [`source`](#-zend_common--license--source)
* [`content`](#-zend_common--license--content)

##### <a name="-zend_common--license--source"></a>`source`

Data type: `Optional[String[1]]`

Source path or puppet URL to license file

Default value: `undef`

##### <a name="-zend_common--license--content"></a>`content`

Data type: `Optional[String[1]]`

Contents of the license file

Default value: `undef`

### <a name="zend_common--repo"></a>`zend_common::repo`

Configure the ZendPHP package repositories depending on OS and version

#### Examples

##### Without parameters

```puppet
include zend_common::repo
```

##### With product other than ZendPHP

```puppet
class { 'zend_common::repo':
  product      => 'ZendHQ',
  support_urls => {
    supported_platforms => 'https://help.zend.com/zendphp/current/content/installation/zendhq_supported_platforms.htm',
  },
}
```

##### With credentials

```puppet
class { 'zend_common::repo':
  creds => {
    username => '<ZEND_USERNAME>',
    password => '<ZEND_PASSWORD>',
  }
}
```

#### Parameters

The following parameters are available in the `zend_common::repo` class:

* [`product`](#-zend_common--repo--product)
* [`creds`](#-zend_common--repo--creds)
* [`key`](#-zend_common--repo--key)
* [`support_urls`](#-zend_common--repo--support_urls)

##### <a name="-zend_common--repo--product"></a>`product`

Data type: `Enum['ZendPHP', 'ZendHQ']`

Name of the Zend product

Default value: `'ZendPHP'`

##### <a name="-zend_common--repo--creds"></a>`creds`

Data type: `Optional[Hash]`

ZendPHP repo credentials

Options:

* **username** `String`: ZendPHP repo username
* **password** `String`: ZendPHP repo password

Default value: `undef`

##### <a name="-zend_common--repo--key"></a>`key`

Data type: `Hash`

ZendPHP repo key

Options:

* **id** `String`: ZendPHP repo key id
* **source** `String`: ZendPHP repo key source URL

Default value:

```puppet
{
    id     => '799058698E65316A2E7A4FF42EAE1437F7D2C623',
    source => 'https://repos.zend.com/zend.key',
  }
```

##### <a name="-zend_common--repo--support_urls"></a>`support_urls`

Data type: `Hash`

Links to relevant Zend product documentation

Options:

* **supported_platforms** `String`: Link to the supported platforms for the relevant Zend product

Default value:

```puppet
{
    supported_platforms => 'https://help.zend.com/zendphp/current/content/introduction/supported_platforms.htm',
  }
```

